@@ -140,7 +140,7 @@ def do_test_script_config(brick, fid):
         (brick.config.motors[0].accel, 14),
         (brick.config.motors[1].decel, 4),
         (brick.config.settings.brakeDecelThr, 88),
-        (brick.config.settings.notchBounds[3], 0x90),
+        (brick.config.settings.notchBounds[2], 0x90),
         (brick.config.lights.startupBrightness[4], 55),
         (brick.config.motors[0].invert, False),
         (brick.config.motors[1].invert, True),
@@ -309,9 +309,9 @@ def test_dac(brick):
         (63, 0xB6),
     ]
     ok = True
-    i2c_write(b, 0, 0)
+    i2c_write(brick, 0, 0)
     for reg in registers:
-        v = i2c_read(b, reg[0])
+        v = i2c_read(brick, reg[0])
         if not v[0] == reg[1]:
             ok = False
     return ok
@@ -641,7 +641,7 @@ combo_fx = [
 ]
 
 
-if __name__ == "__main__":
+def main():
     parser = argparse.ArgumentParser(
         description="PFx Brick self test.  Most tests are run by default but individual tests can be omitted using  command line arguments.",
         prefix_chars="-+",
@@ -922,6 +922,11 @@ if __name__ == "__main__":
 
     b.close()
 
+
+if __name__ == "__main__":
+    main()
+
+
 # b.play_audio_file(7)
 # time.sleep(5)
 # print("Seeking...")
